==> ContactsPortlet-1.0.2-sources.jar: jsp/WEB_002dINF/jsp/contact_002djQM_jsp.java <==
package jsp.WEB_002dINF.jsp;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;

public final class contact_002djQM_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static java.util.List _jspx_dependants;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    JspFactory _jspxFactory = null;
    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      _jspxFactory = JspFactory.getDefaultFactory();
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n\n<rs:resourceURL var=\"addImg\" value=\"rs/famfamfam/silk/1.3/add.png\"/>\n<rs:resourceURL var=\"delImg\" value=\"rs/famfamfam/silk/1.3/delete.png\"/>\n\n<div class=\"contact\" title=\"");
      out.write("${contact.surname}");
      out.write(',');
      out.write(' ');
      out.write("${contact.title}");
      out.write(' ');
      out.write("${contact.firstname}");
      out.write("\">\n\n    <c:choose>\n        <c:when test=\"");
      out.write("${!empty contact.imageURI}");
      out.write("\">\n            <div class=\"contact-photo\" rel=\"");
      out.write("${contact.imageURI}");
      out.write("\" ></div>\n        </c:when>\n        <c:otherwise>\n            <div class=\"contact-photo\">\n                <img src=\"");
      out.write("${BASEURL}");
      out.write("/images/image_unavailable.jpg\"/>\n            </div>\n        </c:otherwise>\n    </c:choose>\n    \n    \n    \n    <strong>");
      out.write("${contact.surname}");
      out.write(',');
      out.write(' ');
      out.write("${contact.title}");
      out.write(' ');
      out.write("${contact.firstname}");
      out.write("</strong><br />\n    ");
      out.write("${contact.position}");
      out.write(' ');
      out.write('-');
      out.write(' ');
      out.write("${contact.department}");
      out.write("\n    <br />                                     \n\n\n    <c:forEach items=\"");
      out.write("${contact.phoneNumbers}");
      out.write("\" var=\"phoneNumber\">\n        <img style=\"vertical-align:middle\" src=\"");
      out.write("${pageContext.request.contextPath}");
      out.write("/images/telephone.png\" height=\"16\" width=\"16\" alt=\"<spring:message code=\"contact.telephone.title\"/>\" title=\"<spring:message code=\"contact.telephone.title\"/>\"/> \n        ");
      out.write("${ phoneNumber.label }");
      out.write(':');
      out.write(' ');
      out.write("${ phoneNumber.phoneNumber }");
      out.write("\n        <br /> \n    </c:forEach>\n\n    <c:forEach items=\"");
      out.write("${contact.emailAddresses}");
      out.write("\" var=\"emailAddress\">\n        <img style=\"vertical-align:middle\" src=\"");
      out.write("${pageContext.request.contextPath}");
      out.write("/images/email.png\" height=\"16\" width=\"16\" alt=\"Email\" title=\"<spring:message code=\"contact.email.title\"/>\"/>\n             <c:out value=\"");
      out.write("${ emailAddress.label }");
      out.write("\" default=\"NULL\"/>: <c:out value=\"");
      out.write("${ emailAddress.emailAddress }");
      out.write("\" default=\"NULL\"/><br/>\n    </c:forEach>\n\n\n    <c:if test=\"");
      out.write("${!empty contact.primaryAddress}");
      out.write("\">\n        ");
      out.write("${contact.primaryAddress.building}");
      out.write(',');
      out.write(' ');
      out.write("${contact.primaryAddress.street}");
      out.write("<br/>\n    </c:if>\n\n        <div style=\"clear: both;\"></div>\n        \n            \n            \n</div>");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          out.clearBuffer();
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      if (_jspxFactory != null) _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> ContactsPortlet-1.0.4-sources.jar: jsp/WEB_002dINF/jsp/contact_002djQM_jsp.java <==
package jsp.WEB_002dINF.jsp;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;

public final class contact_002djQM_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static java.util.List _jspx_dependants;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    JspFactory _jspxFactory = null;
    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      _jspxFactory = JspFactory.getDefaultFactory();
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n\n<rs:resourceURL var=\"addImg\" value=\"rs/famfamfam/silk/1.3/add.png\"/>\n<rs:resourceURL var=\"delImg\" value=\"rs/famfamfam/silk/1.3/delete.png\"/>\n\n<div class=\"contact\" title=\"");
      out.write("${contact.surname}");
      out.write(',');
      out.write(' ');
      out.write("${contact.title}");
      out.write(' ');
      out.write("${contact.firstname}");
      out.write("\">\n\n    <c:choose>\n        <c:when test=\"");
      out.write("${!empty contact.imageURI}");
      out.write("\">\n            <div class=\"contact-photo\" rel=\"");
      out.write("${contact.imageURI}");
      out.write("\" ></div>\n        </c:when>\n        <c:otherwise>\n            <div class=\"contact-photo\">\n                <img src=\"");
      out.write("${BASEURL}");
      out.write("/images/image_unavailable.jpg\"/>\n            </div>\n        </c:otherwise>\n    </c:choose>\n    \n    \n    \n    <strong>");
      out.write("${contact.surname}");
      out.write(',');
      out.write(' ');
      out.write("${contact.title}");
      out.write(' ');
      out.write("${contact.firstname}");
      out.write("</strong><br />\n    ");
      out.write("${contact.position}");
      out.write(' ');
      out.write('-');
      out.write(' ');
      out.write("${contact.department}");
      out.write("\n    <br />                                     \n\n\n    <c:forEach items=\"");
      out.write("${contact.phoneNumbers}");
      out.write("\" var=\"phoneNumber\">\n        <img style=\"vertical-align:middle\" src=\"");
      out.write("${pageContext.request.contextPath}");
      out.write("/images/telephone.png\" height=\"16\" width=\"16\" alt=\"<spring:message code=\"contact.telephone.title\"/>\" title=\"<spring:message code=\"contact.telephone.title\"/>\"/> \n        ");
      out.write("${ phoneNumber.displayType }");
      out.write(": <a href=\"tel:");
      out.write("${ phoneNumber.phoneNumber }");
      out.write('"');
      out.write('>');
      out.write("${ phoneNumber.phoneNumber }");
      out.write("</a>\n        <br /> \n    </c:forEach>\n\n    <c:forEach items=\"");
      out.write("${contact.emailAddresses}");
      out.write("\" var=\"emailAddress\">\n        <img style=\"vertical-align:middle\" src=\"");
      out.write("${pageContext.request.contextPath}");
      out.write("/images/email.png\" height=\"16\" width=\"16\" alt=\"Email\" title=\"<spring:message code=\"contact.email.title\"/>\"/>\n             <c:out value=\"");
      out.write("${ emailAddress.displayType }");
      out.write("\" default=\"NULL\"/>: <a href=\"mailto:\"><c:out value=\"");
      out.write("${ emailAddress.emailAddress }");
      out.write("\" default=\"NULL\"/></a><br/>\n    </c:forEach>\n\n\n    <c:if test=\"");
      out.write("${!empty contact.primaryAddress}");
      out.write("\">\n        ");
      out.write("${contact.primaryAddress.building}");
      out.write(',');
      out.write(' ');
      out.write("${contact.primaryAddress.street}");
      out.write("<br/>\n    </c:if>\n\n        <div style=\"clear: both;\"></div>\n        \n            \n            \n</div>");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          out.clearBuffer();
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      if (_jspxFactory != null) _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
